@@ -47,12 +47,12 @@ def get_spec(json_file: str, logger: logging.Logger) -> Spec:
     with open(json_file) as f:
         j = json.loads(f.read())
 
-    r, msg = validate(logger, j)
-    if not r:
-        print(msg)
-        exit()
 
     spec.decompile(j)
+    failed = validate(logger, spec)
+    if len(failed):
+        print(msg)
+        exit()
 
     return spec
 
